@@ -48,9 +48,9 @@ c            default trace output is requested. Open disk file
       endif
 c
       call ciniASObs
-      if(ObsPlane .eq. horizontal ) then
+      if(abs(ObsPlane) .eq. horizontal ) then
          call csetObsZ(cxyz2det)
-      elseif(ObsPlane .eq. perpendicular ) then
+      elseif(abs(ObsPlane) .eq. perpendicular ) then
          call csetObsZ(cxyz2prim)
       elseif(ObsPlane .eq.  notUsed ) then
 c           Nothing to do. observation is at height =
@@ -128,7 +128,7 @@ c
 #include "Zobsv.h"
 
       external converter  ! cxyz2prim or cxyz2det
-c                           depending on ObsPlane =2, 1
+c                           depending on |ObsPlane| =2, 1
       integer i
       record /coord/ temp
 c        compute z from the base detector.
